@@ -7,13 +7,11 @@ loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendDropPointController").getLogger()
 
 class SendDropPointController(SendCoTAbstractController):
-    def __init__(self, RawCoT=None):
+    def __init__(self, RawCoT):
         try:
             tempObject = super().Event.dropPoint()
             object = SendDropPoint()
-            if RawCoT is not None:
-                self.fill_object(object, tempObject, RawCoT)
-            else:
-                pass
+            self.fill_object(object, tempObject, RawCoT)
         except Exception as e:
-            logger.error("there has been an exception in the creation of the send drop point object " + str(e))
\ No newline at end of file
+            logger.error("there has been an exception in the creation of the send drop point object " + str(e))
+            return -1
\ No newline at end of file
