@@ -1,7 +1,10 @@
+
+from FreeTAKServer.controllers.configuration.MainConfig import MainConfig
+
 class OrchestratorConstants:
     def __init__(self):
         self.CoTIP = "0.0.0.0"
-        self.COTPORT = 8087
+        self.COTPORT = MainConfig.CoTServicePort
         self.APIPORTARG = '-APIPort'
         self.COTPORTARG = '-CoTPort'
         self.IPARG = "-IP"
@@ -11,4 +14,6 @@ class OrchestratorConstants:
         self.COTIPDESC = 'the IP you would like FreeTAKServer to run receive connections on'
         self.FULLDESC = 'FreeTAKServer startup settings'
         self.HEALTHCHECK = 'HealthCheck'
-        self.LOCALHOST = '127.0.0.1'
\ No newline at end of file
+        self.LOCALHOST = '127.0.0.1'
+
+        self.DEFAULTCONNECTIONGEOCHATOBJ = MainConfig.ConnectionMessage
\ No newline at end of file
