@@ -1,12 +1,11 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.KeywordsVariables import KeywordsVariables as vars
 
-class Keywords(FTSProtocolObject):
+class Keywords:
     def __init__(self):
         self.INTAG = None
 
     @staticmethod
-    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
+    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
         keywords = Keywords()
 
         keywords.setINTAG(INTAG)
