@@ -1,11 +1,10 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.MimeTypeVariables import MimeTypeVariables as vars
-class MimeType(FTSProtocolObject):
+class MimeType:
     def __init__(self):
         self.INTAG = None
 
     @staticmethod
-    def ExcheckUpdate(INTAG = vars.ExcheckUpdate().INTAG):
+    def CreateExCheckTemplate(INTAG = vars.CreateExCheckTemplate().INTAG):
         mimetype = MimeType()
         mimetype.setINTAG(INTAG)
         return mimetype
