@@ -8,12 +8,12 @@ class MissionChange:
     def __init__(self):
         pass
     @staticmethod
-    def ExcheckUpdate():
+    def CreateExCheckTemplate():
         missionchange = MissionChange()
-        missionchange.contentResource = ContentResource.ExcheckUpdate()
-        missionchange.creatorUid = CreatorUid.ExcheckUpdate()
-        missionchange.missionName = MissionName.ExcheckUpdate()
-        missionchange.timestamp = Timestamp.ExcheckUpdate()
-        missionchange.type = Type.ExcheckUpdate()
+        missionchange.contentresource = ContentResource.CreateExCheckTemplate()
+        missionchange.creatoruid = CreatorUid.CreateExCheckTemplate()
+        missionchange.missionname = MissionName.CreateExCheckTemplate()
+        missionchange.timestamp = Timestamp.CreateExCheckTemplate()
+        missionchange.type = Type.CreateExCheckTemplate()
         return missionchange
 
