@@ -5,8 +5,8 @@ class MissionChanges:
         pass
 
     @staticmethod
-    def ExcheckUpdate():
+    def CreateExCheckTemplate():
         missionchanges = MissionChanges()
-        missionchanges.MissionChange = MissionChange.ExcheckUpdate()
+        missionchanges.missionchange = MissionChange.CreateExCheckTemplate()
         return missionchanges
 
