@@ -1,12 +1,11 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.SizeVariables import SizeVariables as vars
 
-class Size(FTSProtocolObject):
+class Size:
     def __init__(self):
         self.INTAG = None
 
     @staticmethod
-    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
+    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
         size = Size()
 
         size.setINTAG(INTAG)
