@@ -16,8 +16,21 @@ class Uid:
         uid.setDroid(DROID)
         return uid
 
+    @staticmethod
+    def CreateExCheckTemplate(INTAG = vars.CreateExCheckTemplate().INTAG):
+        uid = Uid()
+        uid.setINTAG(INTAG)
+        return uid
+
     def getDroid(self):
         return self.Droid
 
     def setDroid(self, Droid = None):
         self.Droid = Droid
+
+    def getINTAG(self):
+        return self.INTAG
+
+    def setINTAG(self, INTAG = None):
+        self.INTAG = INTAG
+
