@@ -1,11 +1,6 @@
 class NameVariables:
     @classmethod
-    def ExcheckUpdate(cls):
-        cls.INTAG = None
-        return cls
-
-    @classmethod
-    def Checklist(cls):
+    def CreateExCheckTemplate(cls):
         cls.INTAG = None
         return cls
 
