@@ -1,6 +1,7 @@
 class UidVariables:
     def __init__(self):
         self.DROID = None
+        self.INTAG = None
 
     @classmethod
     def connection(cls):
@@ -10,4 +11,9 @@ class UidVariables:
     @classmethod
     def UserUpdate(cls):
         cls.Droid = None
+        return cls
+
+    @classmethod
+    def CreateExCheckTemplate(cls):
+        cls.INTAG = None
         return cls
\ No newline at end of file
